@@ -148,7 +148,7 @@ impl<'a> WSClientInternal<'a> {
     // Handle a text msg from Message::Text or Message::Binary
     // Returns true if gets a normal message, otherwise false
     fn handle_msg(&self, txt: &str) -> bool {
-        debug!("{}", txt);
+        println!("{}", txt);
         match (self.on_misc_msg)(txt) {
             MiscMessage::Misc => false,
             MiscMessage::Pong => {
