@@ -15,6 +15,15 @@ mod binance_spot {
         );
     }
 
+    #[test]
+    fn subscribe_all_bbo() {
+        gen_test_code!(
+            BinanceSpotWSClient,
+            subscribe,
+            &vec!["!bookTicker".to_string()]
+        );
+    }
+
     #[test]
     fn subscribe_raw_json() {
         gen_test_code!(
@@ -107,6 +116,15 @@ mod binance_inverse_future {
         );
     }
 
+    #[test]
+    fn subscribe_all_bbo() {
+        gen_test_code!(
+            BinanceInverseWSClient,
+            subscribe,
+            &vec!["!bookTicker".to_string()]
+        );
+    }
+
     #[test]
     fn subscribe_trade() {
         gen_test_code!(
@@ -190,6 +208,15 @@ mod binance_linear_future {
         );
     }
 
+    #[test]
+    fn subscribe_all_bbo() {
+        gen_test_code!(
+            BinanceLinearWSClient,
+            subscribe,
+            &vec!["!bookTicker".to_string()]
+        );
+    }
+
     #[test]
     fn subscribe_trade() {
         gen_test_code!(
@@ -273,6 +300,15 @@ mod binance_inverse_swap {
         );
     }
 
+    #[test]
+    fn subscribe_all_bbo() {
+        gen_test_code!(
+            BinanceInverseWSClient,
+            subscribe,
+            &vec!["!bookTicker".to_string()]
+        );
+    }
+
     #[test]
     fn subscribe_trade() {
         gen_test_code!(
@@ -374,6 +410,15 @@ mod binance_linear_swap {
         );
     }
 
+    #[test]
+    fn subscribe_all_bbo() {
+        gen_test_code!(
+            BinanceLinearWSClient,
+            subscribe,
+            &vec!["!bookTicker".to_string()]
+        );
+    }
+
     #[test]
     fn subscribe_trade() {
         gen_test_code!(
